@@ -236,6 +236,22 @@ where
     is_parsable_generic::<Slot, _>(slot)
 }
 
+pub fn is_pow2<T>(bins: T) -> Result<(), String>
+where
+    T: AsRef<str> + Display,
+{
+    bins.as_ref()
+        .parse::<usize>()
+        .map_err(|e| format!("Unable to parse, provided: {}, err: {}", bins, e))
+        .and_then(|v| {
+            if !v.is_power_of_two() {
+                Err(format!("Must be a power of 2: {}", v))
+            } else {
+                Ok(())
+            }
+        })
+}
+
 pub fn is_port<T>(port: T) -> Result<(), String>
 where
     T: AsRef<str> + Display,
